Changelog
=========

0.5.1 (2019-05-23)
------------------

* Added checks for, and optional removal of, zero variance in variables
* Added support for Python 3.7
* (0.5.0 was never released due to failing CI tests)

0.4.3 (2018-04-24)
------------------

* Fixed test that failed after last bug fix

0.4.2 (2018-04-24)
------------------

* Fixed bug with selection of starting column for cross validation of PCA

0.4.1 (2018-04-09)
------------------

* Fixed bug with cross validation of PCA

0.4.0 (2018-04-09)
------------------

* Added cross validations
* Added calculation of distance to model with plots
* Added model overview plots

0.3.0 (2018-04-05)
------------------

* Added R2X and R2Y to the PLS class
* Made plot color selectable also for scoreplots without classes

0.2.0 (2018-03-29)
------------------

* Added a PLS class
* Improved plotting
* Fixed some problems with missing/infinite values

0.1.0 (2018-03-14)
------------------

* First release on PyPI.
